PlayerVolume

Struct PlayerVolume 

pub struct PlayerVolume { /* private fields */ }
Player volume.

Values passed to this struct will be clamped between 0.0 (no sound at all) and 1.0 (regular volume).

Implementations

Source

impl PlayerVolume

pub fn new(volume: f64) -> Self

Create a new PlayerVolume struct with the specified volume.

The passed volume parameter will be clamped between 0.0 and 1.0.

pub fn set(&mut self, volume: f64)

Set the volume.

The passed volume parameter will be clamped between 0.0 and 1.0.

pub fn get(&self) -> f64

Get the wrapped value.