pub fn set_queue(queue: Queue) -> Result<(), Error>Expand description
Set the queue to a list of track.
Note that if shuffle is enabled, the queue will be shuffled immediately after setting it. For
that reason, please use the [play_new_queue] function for setting the queue and then playing a
track at a specific index in that queue.