pub struct PlayerState {
pub position: usize,
pub player_position: Duration,
pub player_volume: PlayerVolume,
pub playback_state: PlaybackState,
pub tracks: Vec<Arc<Track>>,
pub shuffled_track_indices: Vec<usize>,
pub queue_source: QueueSource,
pub shuffle_state: ShuffleState,
pub loop_state: LoopState,
}Expand description
Data structure used to store playback state on the disc and in the RAM at runtime.
Fields
position: usizeThe index of the current track.
It can either point to the tracks variable or shuffled_tracks is shuffle is supported
and set to ShuffleState::On.
player_position: Durationplayer_volume: PlayerVolumeplayback_state: PlaybackStatetracks: Vec<Arc<Track>>shuffled_track_indices: Vec<usize>queue_source: QueueSourceshuffle_state: ShuffleStateloop_state: LoopStateImplementations
Sourceimpl PlayerState
impl PlayerState
pub fn queue_empty(&self) -> bool
pub fn current(&self) -> Option<&Arc<Track>>
Sourcepub fn real_track_index(&self, index: usize) -> Option<usize>
pub fn real_track_index(&self, index: usize) -> Option<usize>
pub fn can_seek(&self) -> bool
pub fn can_play(&self) -> bool
pub fn can_pause(&self) -> bool
pub fn can_toggle_playing(&self) -> bool
pub fn can_go_next(&self) -> bool
pub fn can_go_previous(&self) -> bool
pub fn is_playing(&self) -> bool
pub fn is_paused(&self) -> bool
pub fn stopped(&self) -> bool
pub fn shuffle_enabled(&self) -> bool
pub fn handle_event(&mut self, event: Event)